xquery version "3.1";

module namespace kmg-edition-nav="https://mollenhauer-edition.de/ns/edition-nav";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace xhtml="http://www.w3.org/1999/xhtml";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";
import module namespace transformKMG="http://mollenhauer-edition.de/ns/transform" at "transform.xqm";


declare function kmg-edition-nav:return-card($titleMain as xs:string*, $titleSub as xs:string*, $versions as item()*, $DocTitle as xs:string*) as element(xhtml:div)*{
    let $tg_uri_without_file_ending := replace($DocTitle, '\..*', '')

    (: TEST YEAR FOR decade BUTTON
    let $doc := doc($config:sade-data || $DocTitle)
    let $year := tokenize($doc//tei:sourceDesc/tei:listWit/tei:witness[1]/tei:listWit/tei:witness[1]/tei:desc/text(), "\s")[last()]
    :)

    return
        element div
        {
            attribute class { "card" },
            element div
            {
                attribute class { "card-body" },
                element div
                {
                    element h3
                    {
                        attribute class { "card-title" },
                        $titleMain
                    },
                    element h4
                    {
                        attribute class { "card-subtitle text-muted--lt" },
                        $titleSub
                    }
                }
            },
            element ul
            {
                attribute class { "list-group list-group-flush" },
                    if (count($versions) = 1) then
                        element li
                        {
                            attribute class { "list-group-item" },
                            element a
                            {
                                attribute href { "kmg.html?file=" || $tg_uri_without_file_ending || "&amp;edition=a" },
                                $versions[1]/tei:desc
                            }
                        }
                    else
                        (element li
                        {
                            attribute class { "list-group-item" },
                            element a
                            {
                                attribute href { "kmg.html?file=" || $tg_uri_without_file_ending || "&amp;edition=digital" },
                                "Interaktive textkritische Ansicht mit a als Leittext"
                            }
                        },
                        for $version in $versions
                        return
                            element li
                            {
                                attribute class { "list-group-item" },
                                element a
                                {
                                    attribute href { "kmg.html?file=" || $tg_uri_without_file_ending || "&amp;edition=" || $version/@xml:id },
                                    "Fassung " || $version/@xml:id || ": " || $version/tei:desc
                                }
                            }
                        ),
                    element li
                    {
                        attribute class { "list-group-item" },
                        element a
                        {
                            attribute href { "kmg.html?file=" || $tg_uri_without_file_ending || "&amp;edition=commentary" },
                            "Werkkommentar"
                        }
                    }
            }
        }
};

declare function kmg-edition-nav:single-title-data($DocTitle_var as xs:string*) as element(xhtml:div)*{
    let $titleMain_var := transformKMG:transform(doc($config:sade-data || $DocTitle_var)//tei:title[@type="main"], "navrequest", "none")
    let $titleSub_var := transformKMG:transform(doc($config:sade-data || $DocTitle_var)//tei:title[@type="sub"], "navrequest", "none")
    let $versions_var :=  doc($config:sade-data || $DocTitle_var)//tei:sourceDesc/tei:listWit/tei:witness
    return
        kmg-edition-nav:return-card($titleMain_var, $titleSub_var, $versions_var, $DocTitle_var)
};

declare function kmg-edition-nav:decade-data($decade_button_var as xs:string*) as element(xhtml:div)*{
    if ( $decade_button_var = "all") then
        kmg-edition-nav:all-data()
    else
        for $doc in collection($config:sade-data)
        (: get the second to last digit of the first single witness of the Leittext's year of publication :)
        where tokenize($doc//tei:sourceDesc/tei:listWit/tei:witness[1]//tei:witness[1]/tei:desc/text(), "\s")[last()]
            => substring(3, 1) = $decade_button_var
        return
            kmg-edition-nav:single-title-data(util:document-name($doc))
};

declare function kmg-edition-nav:all-data() as element(xhtml:div)*{
    for $doc in collection($config:sade-data)
    return
        kmg-edition-nav:single-title-data(util:document-name($doc))
};

declare function kmg-edition-nav:title2js() as xs:string*{

    let $len_collection := count(collection($config:sade-data))

    for $doc at $pos in collection($config:sade-data)
    let $year := tokenize($doc//tei:sourceDesc/tei:listWit/tei:witness[1]/tei:listWit/tei:witness[1]/tei:desc/text(), "\s")[last()]
    (: order by $year :)
    return
        if ($pos = $len_collection) then
            '{ "value": "' || ($pos -1) ||  '", "text": "' || normalize-space($doc//tei:title[@type="main"]) || ' ' || $year || '", "DocTitle_TextGrid": "' || util:document-name($doc) || '" }'
        else
            '{ "value": "' || ($pos -1) ||  '", "text": "' || normalize-space($doc//tei:title[@type="main"]) || ' ' || $year || '", "DocTitle_TextGrid": "' || util:document-name($doc) || '"},'
};

declare function kmg-edition-nav:title2js_list($node as node(), $model as map (*)) as node()*{
        <script>
        var data_content = [
        {kmg-edition-nav:title2js()}
        ]
        </script>
};